<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mots?lang_cible=en
// ** ne pas modifier le fichier **

return [

	// M
	'mots_description' => 'Keywords and keywords groups',
	'mots_slogan' => 'Management of keywords and keywords groups in SPIP',
];
